"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getQuizSessions = getQuizSessions;
exports.getQuizSession = getQuizSession;
exports.reopenQuizSession = reopenQuizSession;
exports.submitOutstandingQuizSession = submitOutstandingQuizSession;

var _Fetcher = _interopRequireDefault(require("../../common/util/Fetcher"));

var _quizCommon = require("@instructure/quiz-common");

var _callHandlers = require("../../common/api/callHandlers");

function getQuizSessions(quizId) {
  var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
  var url = "/api/quizzes/".concat(quizId, "/quiz_sessions");
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default({
      callType: _quizCommon.QUIZ_SESSIONS_FETCH_CALL
    });
    return fetcher.get(url, params).then(function (response) {
      dispatch((0, _callHandlers.handleQuizSessionsResponse)(response));
    });
  };
}

function getQuizSession(quizSessionId) {
  var url = "/api/quiz_sessions/".concat(quizSessionId);
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default({
      callType: _quizCommon.QUIZ_SESSION_FETCH_CALL
    });
    return fetcher.get(url).then(function (response) {
      dispatch((0, _callHandlers.handleQuizSessionResponse)(response));
    });
  };
}

function reopenQuizSession(quizSessionId) {
  var url = "/api/quiz_sessions/".concat(quizSessionId, "/reopen");
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default({
      callType: _quizCommon.QUIZ_SESSION_REOPEN_CALL
    });
    return fetcher.post(url).then(function (response) {
      dispatch((0, _callHandlers.handleQuizSessionResponse)(response));
    });
  };
}

function submitOutstandingQuizSession(quizSessionId) {
  var url = "/api/quiz_sessions/".concat(quizSessionId, "/autosubmit");
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default({
      callType: _quizCommon.QUIZ_SESSION_AUTOSUBMIT_CALL
    });
    return fetcher.post(url).then(function (response) {
      dispatch((0, _callHandlers.handleQuizSessionResponse)(response));
    });
  };
}